@@ -3,7 +3,7 @@ from colored import stylize
 import json
 import os
 import pkg_resources
-from utils import export_to_csv, export_to_json, show_vulnerablities, \
+from pyraider.utils import export_to_csv, export_to_json, show_vulnerablities, \
     render_package_update_report, scan_vulnerabilities, scan_vulnerable_data, \
     validate_version, fix, auto_fix_all, show_secure_packages, check_latestdb, \
     scan_light_vulnerabilities, export_to_html, show_dependencies
@@ -18,7 +18,7 @@ def read_from_env(export_format=None, export_file_path=None, deep_scan=False, se
     data_dict = {}
     secure_data_dict = []
     data_dict['pyraider'] = []
-    data_dict['version'] = '1.0.15'
+    data_dict['version'] = '1.0.16'
     vul_package_count = 0
     if deep_scan:
         data = scan_vulnerabilities()
@@ -125,7 +125,7 @@ def read_from_file(to_scan_file, export_format=None, export_file_path=None, deep
     data_dict = {}
     secure_data_dict = []
     data_dict['pyraider'] = []
-    data_dict['version'] = '1.0.15'
+    data_dict['version'] = '1.0.16'
     vul_package_count = 0
     _, file_extension = os.path.splitext(to_scan_file)
     if deep_scan:
